===========
Control API
===========

lti
===

.. module:: sympy.physics.control.lti

.. autoclass:: TransferFunction
   :members:

.. autoclass:: Series
   :members:

.. autoclass:: Parallel
   :members:

.. autoclass:: Feedback
   :members:

.. autoclass:: TransferFunctionMatrix
   :members:

.. autoclass:: MIMOSeries
   :members:

.. autoclass:: MIMOParallel
   :members:

.. autoclass:: MIMOFeedback
   :members:

.. autofunction:: gbt

.. autofunction:: bilinear

.. autofunction:: forward_diff

.. autofunction:: backward_diff
